( cd usr/bin ; rm -rf newaliases )
( cd usr/bin ; ln -sf ../../usr/sbin/sendmail newaliases )
( cd usr/bin ; rm -rf mailq )
( cd usr/bin ; ln -sf ../../usr/sbin/sendmail mailq )
( cd usr/lib ; rm -rf sendmail )
( cd usr/lib ; ln -sf ../../../usr/sbin/sendmail sendmail )
( cd etc/rc.d/init.d ; rm -rf postfix )
( cd etc/rc.d/init.d ; ln -sf ../../../usr/sbin/postfix postfix )
#%% begin initialize postfix-2.7.4-i586-P1
( cd /etc
  if [ ! -f aliases ] ; then
    mv aliases-new aliases
  else
    echo "/etc/aliases exists"
    rm aliases-new
  fi
)

( cd /etc
  if  ! grep submission services 1>/dev/null 2>/dev/null; then
     cat >> services <<EOF2
submission      587/tcp
submission      587/udp
EOF2
  fi
  inetd_chk=`ps axww | grep inetd`
  if [ "$inetd_chk.x" != ".x" ]; then
      /bin/killall -HUP inetd
  fi
)

(  cd /etc/postfix

    for conf_file in LICENSE TLS_LICENSE access aliases bounce.cf.default canonical generic header_checks main.cf main.cf.default makedefs.out master.cf relocated transport virtual ; do
    if [ ! -f $conf_file ]; then
         mv new/$conf_file .
    fi
  done

  rm -rf new
)

if [ ! -f /etc/aliases.db ]; then
    /usr/bin/newaliases
fi

#%% end
